@@ -35,6 +35,10 @@ public class vtkTableReader extends vtkDataReader
   public void SetOutput(vtkTable id0)
     { SetOutput_4(id0); }
 
+  private native int ReadMeshSimple_5(String id0,vtkDataObject id1);
+  public int ReadMeshSimple(String id0,vtkDataObject id1)
+    { return ReadMeshSimple_5(id0,id1); }
+
   public vtkTableReader() { super(); }
 
   public vtkTableReader(long id) { super(id); }
